@@ -8,6 +8,7 @@ import shutil
 import tarfile
 import progressbar
 import urllib.request
+from simple_file_checksum import get_checksum
 
 from rayasdk.constants import *
 from rayasdk.logger import log, LogLevels, log_info, log_error, log_verbose
@@ -82,6 +83,8 @@ def launch_command(bash_command, suffix, output_file='', silent=False,
     if platform.system() == 'Windows':
         docker_command = f'powershell "{docker_command}"'
 
+    # print(docker_command)
+
     ret = subprocess.call(docker_command, shell=True)
 
 
@@ -96,7 +99,7 @@ def download_simulator():
         shutil.rmtree(SIMS_HOME)
     except FileNotFoundError:
         pass
-    print(f'Downloading version {GARYSIM_VERSION}...')
+    print(f'Downloading Ra-Ya SDK v{GARYSIM_VERSION}...')
     SIMS_HOME.mkdir(parents=True, exist_ok=True)
     try:
         urllib.request.urlretrieve(GARYSIM_URL, str(SIM_TARPATH), 
@@ -106,7 +109,7 @@ def download_simulator():
         return False
     log_info(f'Checking downloaded file...')
     try:
-        sha256 = hashlib.sha256(open(SIM_TARPATH,'rb').read()).hexdigest()
+        sha256 = get_checksum(SIM_TARPATH, algorithm="SHA256")
     except FileNotFoundError:
         log_error('Download error, try again.')
         return False
@@ -138,7 +141,7 @@ def run_simulator_bridge():
             ('/opt/raya_os/run_bridge_unity.sh'),
             suffix='simbridge',
             working_dir='/root', 
-            ports=['10000:10000', '8789:8789', '8000:8000']
+            ports=['10000:10000', '8789-8890:8789-8890', '8000:8000']
         )
     p.kill()
     p.wait()
@@ -183,8 +186,14 @@ def scanner(min_domain=1, max_domain=100, silent=False):
         )
     if not silent:
         log_info('\nFinish scanning')
-    file = open(scan_file, 'r')
-    lines = file.readlines()
+
+    try:
+        file = open(scan_file, 'r')
+        lines = file.readlines()
+    except UnicodeDecodeError:
+        file = open(scan_file, 'r', encoding='utf_16_le')
+        lines = file.readlines()
+
     for line in lines:
         try:
             if platform.system() == 'Linux':
@@ -262,7 +271,7 @@ def check_container():
                     image=f'{RAYAENV_DOCKER_IMGNAME}:{img_tag}'
                 )
 
-    log_info(f'Downloading image (only once)...')
+    log_info(f'Downloading Ra-Ya OS v{RAYAENV_DOCKER_VERSION} (only once)...')
     try:
         urllib.request.urlretrieve(RAYAENV_DOCKER_URL, str(RAYAENV_DOCKER_IMGPATH),
                                 MyProgressBar())
@@ -271,7 +280,7 @@ def check_container():
         return False
     log_info(f'Checking downloaded file...')
     try:
-        sha256 = hashlib.sha256(open(RAYAENV_DOCKER_IMGPATH,'rb').read()).hexdigest()
+        sha256 = get_checksum(RAYAENV_DOCKER_IMGPATH, algorithm="SHA256")
     except FileNotFoundError:
         log_error('Download error, try again.')
         return False
@@ -286,7 +295,6 @@ def check_container():
     if ret != 0:
         log_error('Error creating the image, try again.')
         return False
-    log_info('Image create correctly, you can now execute \'rayasdk\'')
 
     return True
 
